@@ -36,34 +36,34 @@ def pytest_addoption(parser):
     group = parser.getgroup("pytest-otel", "report OpenTelemetry traces for tests executed.")
 
     group.addoption(
-        "--endpoint",
+        "--otel-endpoint",
         dest="endpoint",
         help="URL for the APM server.(OTEL_EXPORTER_OTLP_ENDPOINT)",
     )
     group.addoption(
-        "--headers",
+        "--otel-headers",
         dest="headers",
         help="Additional headers to send (i.e.: key1=value1,key2=value2).(OTEL_EXPORTER_OTLP_HEADERS)",  # noqa: E501
     )
     group.addoption(
-        "--service-name",
+        "--otel-service-name",
         dest="service_name",
         default="Pytest_Otel_reporter",
         help="Name of the service.(OTEL_SERVICE_NAME)",
     )
     group.addoption(
-        "--session-name",
+        "--otel-session-name",
         dest="session_name",
         default="Test Suite",
         help="Name for the Main span reported.",
     )
     group.addoption(
-        "--traceparent",
+        "--otel-traceparent",
         dest="traceparent",
         help="Trace parent.(TRACEPARENT) see https://www.w3.org/TR/trace-context-1/#trace-context-http-headers-format",  # noqa: E501
     )
     group.addoption(
-        "--insecure",
+        "--otel-insecure",
         dest="insecure",
         default=False,
         help="Disables TLS.(OTEL_EXPORTER_OTLP_INSECURE)",
@@ -74,7 +74,12 @@ def pytest_addoption(parser):
         default="./otel-traces-file-output.json",
         help="If the Otel endpoint is not set, the spans will be saved to a file (./otel-traces-file-output.txt)",
     )
-
+    group.addoption(
+        "--otel-debug",
+        dest="otel_debug",
+        default=False,
+        help="",
+    )
 
 def init_otel():
     """Init the OpenTelemetry settings"""
@@ -161,8 +166,9 @@ def traceparent_context(traceparent):
 def pytest_sessionstart(session):
     """Uses the commandline parameter to define the environment variables used by OpenTelemetry"""
     global service_name, traceparent, session_name, insecure, in_memory_span_exporter, otel_span_file_output
-    LOGGER.setLevel(logging.DEBUG)
     config = session.config
+    if config.getoption("otel_debug"):
+        LOGGER.setLevel(logging.DEBUG)
     service_name = config.getoption("service_name")
     session_name = config.getoption("session_name")
     traceparent = config.getoption("traceparent")
@@ -256,7 +262,7 @@ def pytest_runtest_call(item):
             LOGGER.debug("test.last_value {}".format(last_value))
             stack_trace = repr(traceback.format_exception(last_type, last_value, last_traceback))
             span.set_attribute("test.stack_trace", "{}".format(stack_trace))
-            if hasattr(last_value, "args") and len(getattr(last_value, 'args')) > 0:
+            if hasattr(last_value, "args") and len(getattr(last_value, 'args', [])) > 0:
                 span.set_attribute("test.error", "{}"
                                    .format(last_value.args[0]))
 
